library(ape)

## Read the alignment from phylip format
sylvia.seq.ali <- read.dna("sylviaseq.phy")
outGroup <- "Z73494"

## Read the alignment from R workspace
##  It includes sylvia.seq.ali data.
#load("sylvia.RData")

## Estimate the distance using TN93 + G model.
# dist.dna does not allow GTR.  
# TN93 is the most parameter rich model implemented in ape
syl.TN93G <- dist.dna(sylvia.seq.ali, model = "TN93",gamma = TRUE, pairwise.deletion = TRUE)

## Estimate the NJ tree with TN93 G model.
nj.sylvia.TN93G <- njs(syl.TN93G)

## Reroot by outGroup
nj.sylvia.TN93G <- root(nj.sylvia.TN93G,outGroup,r=T)

## ladderize from bottom
#nj.sylvia.TN93G <- ladderize(nj.sylvia.TN93G,TRUE)


## Bootstrap analysis. 
## 3 means that the codon sequences will be resampled together.
## See help(boot.phylo)
#nj.boot.sylvia.codon <- boot.phylo(nj.sylvia.TN93G,
#                                   sylvia.seq.ali,
#                                   function(xx) nj(dist.dna(xx,
#                                   model = "TN93", gamma = TRUE,
#                                   pairwise.deletion = TRUE)),
#                                   200, 3)


nj.boot.sylvia.codon <- boot.phylo(nj.sylvia.TN93G, 
                                       sylvia.seq.ali,     
                                       function(xx) 
                                       root(njs(dist.dna(xx, model = "TN93", pairwise.deletion = TRUE)), outGroup,r=T), 100)


## Rename the object for NJ tree.
nj.est <- nj.sylvia.TN93G

## If the data retrieved from sylvia.RData,
## IDs can be replaced by the scientific name.
#nj.est$tip.label <- taxa.sylvia[nj.est$tip.label]

## The bootstrap values will be labeled as percents.
#nj.est$node.label <- nj.boot.sylvia.codon / 2
nj.est$node.label <- nj.boot.sylvia.codon

## Plot the tree and BS values
plot(nj.est,no.margin = TRUE)
#nodelabels(nj.est$node.label, bg = "white")
nodelabels(nj.est$node.label,frame = "n")
add.scale.bar(y = 0.5, length = 0.01)

## Save the resultant tree with BS as a newick format
write.tree(nj.est, "sylvia_nj_TN93GPart.tre")
